/*
 * linux/kernel/char/dualcpu.h
 *
 * MMSP2 DUAL CPU Interface include file
 *
 ghcstop: ̺κ wince bsp codec.h Ѱ . wince bsp codec.h  
 
 */

#ifndef _MMSP2_DUALCPU_H_
#    define _MMSP2_DUALCPU_H_

#    include "wincetype.h"


/*
 * 20041130: fixed by mes
 */
#    define VIDEO_FW_041126		1

//------------------------------------------------------------------------------
//	CODEC COMMAND
//------------------------------------------------------------------------------
#define	MP_CMD_NULL			0

//------------------------------------------------------------------------------
//	CODEC TYPE
//------------------------------------------------------------------------------

#define	MP_CODEC_NULL		-1
#define	MP_CODEC_MP4D		0
#define	MP_CODEC_MP4D_DIVX3	1
#define	MP_CODEC_H263D		2
#define	MP_CODEC_MP2D		3
#define	MP_CODEC_MJPD		4
#define	MP_CODEC_MP4E		5
#define	MP_CODEC_WMVD		6
#define MP_CODEC_MP3D       7
#define	MP_CODEC_MP1D		9
//	20050608 walker jpeg encoder ߰ 
#define	MP_CODEC_MJPE		10

// 20050429 walker arm940base setting ϱ system ̽ . 
#define	MP_SYSTEM_INIT		8



//------------------------------------------------------------------------------
//	CODEC COMMAND
//------------------------------------------------------------------------------

/* ARM940 command */
#define	MP_CMD_INIT					1
#define MP_CMD_INIT_BUF     		16
#define	MP_CMD_RUN					2
#define	MP_CMD_RELEASE				4
#define	MP_CMD_GETINFO				6
#define	MP_CMD_940IDLE				5
// walker [bf109up] modified 2005-03-02 10:49
// init / relase for seek
#define	MP_CMD_INIT_FOR_SEEK		7
#define	MP_CMD_RELEASE_FOR_SEEK		8

/* ARM920 command */
#define MP_CMD_DISPLAY      		17

/* general */
#define	MP_CMD_ACK					5
#define	MP_CMD_FAIL					15

//------------------------------------------------------------------------------
//	CODEC VERSION
//  Length : 16bits
//------------------------------------------------------------------------------

#define	CODEC_VER_DIVX_311	311
#define	CODEC_VER_DIVX_500	500
#define	CODEC_VER_XVID		900



//------------------------------------------------------------------------------
//  CODEC INIT. PARAMETER
//------------------------------------------------------------------------------
// MPEG2 DECODER
typedef struct _MP2D_INIT_PARAM_
{
    U16             Command;
    U16             CodecType;
    U16             Width;
    U16             Height;
    U16             CodecVersion;
    U16             RL_L;
    U16             RL_H;
    U16             RL_Length;  // in kbytes
    U16             StreamBufferPaddrL;
    U16             StreamBufferPaddrH;
} MP2D_INIT_PARAM;

// MPEG4 ENCODER
typedef struct _MP4E_INIT_PARAM_
{
    U16             Command;
    U16             CodecType;
    U16             Width;
    U16             Height;
    U16             CodecVersion;
    U16             Framerate;
    U16             RcPeriod;
    U16             RcReactionPeriod;
    U16             RcReactionRation;
    U16             MaxKeyInterval;
    U16             MaxQuantizer;
    U16             MinQuantizer;
    U16             SearchRrange;
} MP4E_INIT_PARAM;

// MJPEG DECODER
typedef struct _MJPD_INIT_PARAM_
{
    U16             Command;
    U16             CodecType;
} MJPD_INIT_PARAM;


//------------------------------------------------------------------------------
//  CODEC RUN PARAMETER
//------------------------------------------------------------------------------
// MPEG2 DECODER
typedef struct _MP2D_RUN_PARAM_
{
    U16             Command;
    U16             CodecType;
    U16             StreamBufferPaddrL;
    U16             StreamBufferPaddrH;
} MP2D_RUN_PARAM;

// MPEG4 DECODER
typedef struct _MP4E_RUN_PARAM_
{
    U16             Command;
    U16             CodecType;
    U16             StreamBufferPaddrL;
    U16             StreamBufferPaddrH;
    U32             StreamBufferSize;
} MP4E_RUN_PARAM;

// MJPEG DECODER
typedef struct _MJPD_RUN_PARAM_
{
    U16             Command;
    U16             CodecType;
} MJPD_RUN_PARAM;


//------------------------------------------------------------------------------
//  CODEC SET OFFSET ADDR PARAMETER
//------------------------------------------------------------------------------
// MJPEG DECODER
typedef struct _MJPD_OFFSET_PARAM_
{
    U16             Command;
    U16             CodecType;
    U16             LU_Offset;
    U16             CB_Offset;
    U16             CR_Offset;
} MJPD_OFFSET_PARAM;


//------------------------------------------------------------------------------
//  CODEC RELEASE PARAMETER
//------------------------------------------------------------------------------
// MPEG2 DECODER
typedef struct _MP2D_REL_PARAM_
{
    U16             Command;
    U16             CodecType;
} MP2D_REL_PARAM;

// MPEG4 DECODER
typedef struct _MP4D_REL_PARAM_
{
    U16             Command;
    U16             CodecType;
} MP4D_REL_PARAM;

// MPEG4 ENCODER
typedef struct _MP4E_REL_PARAM_
{
    U16             Command;
    U16             CodecType;
} MP4E_REL_PARAM;

// MJPEG DECODER
typedef struct _MJPD_REL_PARAM_
{
    U16             Command;
    U16             CodecType;
} MJPD_REL_PARAM;

// walker[bf109up] modified 2004/09/14/10/37
// new information for mpeg4

/******************************************************************************
 *
 *  ARM 920T COMMAND
 *
 ******************************************************************************/

///////////////////////////////////////////////////////////////////////////////
//
//   send struct  to ARM 940 
//
/////////////////////////////////////////////////////////////////////////////// 

//------------------------------------------------------------------------------
//  CODEC INIT
//------------------------------------------------------------------------------
// MPEG4 DECODER
typedef struct _MP4D_INIT_PARAM_
{

    U16             Command;    // commands ARM940T Firmware. (codec.h)
    U16             CodecType;  // defines what CODEC do you want to use. (codec.h)
    U16             Width;      // Video image width
    U16             Height;     // Video image height
    U16             CodecVersion;   // defined in codec.h
    U16             RL_L;       // Low 16-bit physical address of RL buffer
    U16             RL_H;       // High 16-bit physical address of RL buffer
    U16             RL_Length;  // 512 (Unit is Kbytes, The Size of RL buffer should be 512KB)
    U16             mbp_a_addr_offset;  // high 16bits addresss for macroblock param A
    U16             mbp_b_addr_offset;  // high 16bits addresss for macroblock param B
    U16             qmat_addr_h;    // high 16bits address for quantizer matrix data save
    U16             qmat_addr_l;    // low 16bits address for quantizer matrix data save
    U16             pred_q_lb_offset;   // 16bit offset address for mpeg4 h/w block's line buffer 
    U16             arm940_offset;  // arm940t's base address
#    if VIDEO_FW_041126         // 20041130: fixed by mes
    U16             non_bframe_max;
    U16             b_frame_max;
#    endif

} MP4D_INIT_PARAM;

//------------------------------------------------------------------------------
//  CODEC INIT BUF
//------------------------------------------------------------------------------
// MPEG4 DECODER
#    if 0                       // ghcstop: mes style 041202 fix
typedef struct _MP4D_INIT_BUF_PARAM_
{

    U16             Command;    // commands ARM940T Firmware. (codec.h)
    U16             buffer_type;    // non bframe buffer of bframe buffer
    U16             buffer_idx; // buffer idx
    U16             luma_offset_addr;   // luma 16bits offset address
    U16             cb_offset_addr; // cb 16bits offset address
    U16             cr_offset_addr; // cr 16bits offset address

} MP4D_INIT_BUF_PARAM;
#    else
//------------------------------------------------------------------------------
//  CODEC INIT BUF
//------------------------------------------------------------------------------
// MPEG4 DECODER
typedef struct _MP4D_INIT_BUF_PARAM_
{
    unsigned short  Command;    // commands ARM940T Firmware. (codec.h)
    unsigned short  BufferType; // non bframe buffer of bframe buffer
    unsigned short  BufferIdx;  // buffer idx
    unsigned short  Y_Offset;   // luma 16bits offset address
    unsigned short  CB_Offset;  // cb 16bits offset address
    unsigned short  CR_Offset;  // cr 16bits offset address
} MP4D_INIT_BUF_PARAM;
#    endif

//------------------------------------------------------------------------------
//  CODEC RUN
//------------------------------------------------------------------------------
// MPEG4 DECODER
typedef struct _MP4D_RUN_PARAM_
{

    U16             Command;    // commands ARM940T Firmware. (codec.h)
    U16             CodecType;  // defines what CODEC do you want to use. (codec.h)
    U16             frames;     // frame number in current received stream /* not implemented */
    U16             stream_length;  // stream length /* not implemented */
    U16             stream_last_marker_h;   // high 16bits data of stream last marker /* not implemented */
    U16             stream_last_marker_l;   // low 16bits data of stream last marker /* not implemented */
    U16             StreamBufferPaddrL; // 16bits low address of stream address 
    U16             StreamBufferPaddrH; // 16bits high address of stream address

} MP4D_RUN_PARAM;

//------------------------------------------------------------------------------
//  CODEC RELEASE : currently not defined
//------------------------------------------------------------------------------

/******************************************************************************
 *
 *  ARM 940T COMMAND
 *
 ******************************************************************************/

#    if 0                       //  κ Ŀο  δ.
//  κ app Ѵ. ghcstop 041202 fix
typedef struct _MP4D_DISPLAY_PARAM_
{
    unsigned short  Command;    // commands ARM940T Firmware. (codec.h)
    unsigned short  BFrame;     // b frame flag in p frame
    unsigned short  DisplayFrames;  // number of frame to display

    unsigned short  Number1;    // #0 frame's number /* not implemented */
    unsigned short  Time1;      // #0 frame's time /* not implemented */
    unsigned short  TimeWidth1; // #0 frame's time width /* not implemented */
    unsigned short  Y_Offset1;  // #0 16bits luma offset address
    unsigned short  CB_Offset1; // #0 16bits cb offset address
    unsigned short  CR_Offset1; // #0 16bits cr offset address

    unsigned short  Number2;    // #1 frame number /* not implemented */
    unsigned short  Time2;      // #1 frame's time /* not implemented */
    unsigned short  TimeWidth2; // #1 frame's time width /* not implemented */
    unsigned short  Y_Offset2;  // #1 16bits luma offset address
    unsigned short  CB_Offset2; // #1 16bits cb offset address
    unsigned short  CR_Offset2; // #1 16bits cr offset address
} MP4D_DISPLAY_PARAM;


#    else
///////////////////////////////////////////////////////////////////////////////
//
//   send struct  to ARM 920 
//
/////////////////////////////////////////////////////////////////////////////// 
typedef struct _MP4D_DISPLAY_PARAM_
{

    U16             Command;    // 0 commands ARM940T Firmware. (codec.h)
    U16             has_bframe; // 1 b frame flag in p frame
    U16             display_frames; // 2 number of frame to display

    U16             time;       // 4 #0 frame's time /* not implemented */
    U16             luma_offset_addr;   // 6 #0 16bits luma offset address
    U16             cb_offset_addr; // 7 #0 16bits cb offset address
    U16             cr_offset_addr; // 8 #0 16bits cr offset address

    U16             remain_frame_time;  // 10 #1 frame's time /* not implemented */
    U16             remain_frame_luma_offset_addr;  // 12 #1 16bits luma offset address
    U16             remain_frame_cb_offset_addr;    // 13 #1 16bits cb offset address
    U16             remain_frame_cr_offset_addr;    // 14 #1 16bits cr offset address

    U16             remain_frame_time1; // 10 #1 frame's time /* not implemented */
    U16             remain_frame_luma_offset_addr1; // 12 #1 16bits luma offset address
    U16             remain_frame_cb_offset_addr1;   // 13 #1 16bits cb offset address
    U16             remain_frame_cr_offset_addr1;   // 14 #1 16bits cr offset address
    U16             dummy;

} MP4D_DISPLAY_PARAM;
#    endif

#    define IOCTL_DUALCPU_MP4D_INIT     _IOW('d', 0x01, MP4D_INIT_PARAM)
#    define IOCTL_DUALCPU_MP4D_INIT_BUF _IOW('d', 0x02, MP4D_INIT_BUF_PARAM)
#    define IOCTL_DUALCPU_MP4D_RUN      _IOW('d', 0x03, MP4D_RUN_PARAM)
#    define IOCTL_DUALCPU_MP4D_RELEASE  _IOW('d', 0x04, MP4D_REL_PARAM)
#    define IOCTL_DUALCPU_MP4D_STATUS   _IOR('d', 0x05, MP4D_DISPLAY_PARAM)

//------------------------------------------------------------------------------
//	CODEC VERSION
//  Length : 16bits
//------------------------------------------------------------------------------

#define	CODEC_VER_WMV_7		0
#define	CODEC_VER_WMV_8		1
#define	CODEC_VER_WMV_9		2

//------------------------------------------------------------------------------
//	WMV DECODER PARAMETERS
//------------------------------------------------------------------------------


typedef struct _WMVD_INIT_PARAM_ {
	unsigned short Command;
	unsigned short CodecType;
	unsigned short Width;
	unsigned short Height;
	unsigned short CodecVersion;
	unsigned long StreamBufferPaddr;
	unsigned long StreamLength;
} WMVD_INIT_PARAM;

typedef struct _WMVD_RUN_PARAM_ {
	unsigned short Command;
	unsigned short CodecType;
	unsigned long StreamBufferPaddr;
	unsigned long StreamLength;
	unsigned long OutputYP2Daddr;
	unsigned long OutputUP2Daddr;
	unsigned long OutputVP2Daddr;
} WMVD_RUN_PARAM;

typedef struct _WMVD_REL_PARAM_ {
	unsigned short Command;
	unsigned short CodecType;
} WMVD_REL_PARAM;			
	


/* WMV Decode IOCTL Commands */
#   define IOCTL_DUALCPU_WMVD_INIT			_IOW('d', 0x50,	WMVD_INIT_PARAM)
#  	define IOCTL_DUALCPU_WMVD_RUN			_IOW('d', 0x51,	WMVD_RUN_PARAM)
# 	define IOCTL_DUALCPU_WMVD_RELEASE		_IOW('d', 0x52,	WMVD_REL_PARAM)

#endif                          // _MMSP2_DUALCPU_H_
